# Ways to do text analysis with dhlab

<!-- start usage-platforms -->

- In the python console or an IDE: [Install dhlab](./docs_installation.md)
- Via [our streamlit apps](https://www.nb.no/dh-lab/apper/)
- In our example Jupyter Notebooks
  - on our website: [nb.no/dhlab/digital_tekstanalyse/](https://www.nb.no/dh-lab/digital-tekstanalyse/)
  - on github: [digital_tekstanalyse](https://github.com/NationalLibraryOfNorway/digital_tekstanalyse)
- With API-calls to the [DH-lab REST-API](https://api.nb.no/dhlab/)
- With R on github: [dhlab-r](https://github.com/NationalLibraryOfNorway/dhlab-r)

<!-- end usage-platforms-->
